@@ -1,7 +1,8 @@
-from typing import Any, cast, Dict, Optional, TYPE_CHECKING, Union
+from typing import Any, cast, Dict, List, Optional, TYPE_CHECKING, Union
 
 import requests
 
+import gitlab
 from gitlab import cli
 from gitlab import exceptions as exc
 from gitlab.base import RequiredOptional, RESTManager, RESTObject
@@ -28,7 +29,7 @@ class ProjectCommit(RESTObject):
 
     @cli.register_custom_action("ProjectCommit")
     @exc.on_http_error(exc.GitlabGetError)
-    def diff(self, **kwargs: Any) -> Union[Dict[str, Any], requests.Response]:
+    def diff(self, **kwargs: Any) -> Union[gitlab.GitlabList, List[Dict[str, Any]]]:
         """Generate the commit diff.
 
         Args:
@@ -41,8 +42,8 @@ class ProjectCommit(RESTObject):
         Returns:
             The changes done in this commit
         """
-        path = f"{self.manager.path}/{self.get_id()}/diff"
-        return self.manager.gitlab.http_get(path, **kwargs)
+        path = f"{self.manager.path}/{self.encoded_id}/diff"
+        return self.manager.gitlab.http_list(path, **kwargs)
 
     @cli.register_custom_action("ProjectCommit", ("branch",))
     @exc.on_http_error(exc.GitlabCherryPickError)
@@ -57,7 +58,7 @@ class ProjectCommit(RESTObject):
             GitlabAuthenticationError: If authentication is not correct
             GitlabCherryPickError: If the cherry-pick could not be performed
         """
-        path = f"{self.manager.path}/{self.get_id()}/cherry_pick"
+        path = f"{self.manager.path}/{self.encoded_id}/cherry_pick"
         post_data = {"branch": branch}
         self.manager.gitlab.http_post(path, post_data=post_data, **kwargs)
 
@@ -65,7 +66,7 @@ class ProjectCommit(RESTObject):
     @exc.on_http_error(exc.GitlabGetError)
     def refs(
         self, type: str = "all", **kwargs: Any
-    ) -> Union[Dict[str, Any], requests.Response]:
+    ) -> Union[gitlab.GitlabList, List[Dict[str, Any]]]:
         """List the references the commit is pushed to.
 
         Args:
@@ -79,13 +80,15 @@ class ProjectCommit(RESTObject):
         Returns:
             The references the commit is pushed to.
         """
-        path = f"{self.manager.path}/{self.get_id()}/refs"
-        data = {"type": type}
-        return self.manager.gitlab.http_get(path, query_data=data, **kwargs)
+        path = f"{self.manager.path}/{self.encoded_id}/refs"
+        query_data = {"type": type}
+        return self.manager.gitlab.http_list(path, query_data=query_data, **kwargs)
 
     @cli.register_custom_action("ProjectCommit")
     @exc.on_http_error(exc.GitlabGetError)
-    def merge_requests(self, **kwargs: Any) -> Union[Dict[str, Any], requests.Response]:
+    def merge_requests(
+        self, **kwargs: Any
+    ) -> Union[gitlab.GitlabList, List[Dict[str, Any]]]:
         """List the merge requests related to the commit.
 
         Args:
@@ -98,8 +101,8 @@ class ProjectCommit(RESTObject):
         Returns:
             The merge requests related to the commit.
         """
-        path = f"{self.manager.path}/{self.get_id()}/merge_requests"
-        return self.manager.gitlab.http_get(path, **kwargs)
+        path = f"{self.manager.path}/{self.encoded_id}/merge_requests"
+        return self.manager.gitlab.http_list(path, **kwargs)
 
     @cli.register_custom_action("ProjectCommit", ("branch",))
     @exc.on_http_error(exc.GitlabRevertError)
@@ -119,7 +122,7 @@ class ProjectCommit(RESTObject):
         Returns:
             The new commit data (*not* a RESTObject)
         """
-        path = f"{self.manager.path}/{self.get_id()}/revert"
+        path = f"{self.manager.path}/{self.encoded_id}/revert"
         post_data = {"branch": branch}
         return self.manager.gitlab.http_post(path, post_data=post_data, **kwargs)
 
@@ -138,7 +141,7 @@ class ProjectCommit(RESTObject):
         Returns:
             The commit's signature data
         """
-        path = f"{self.manager.path}/{self.get_id()}/signature"
+        path = f"{self.manager.path}/{self.encoded_id}/signature"
         return self.manager.gitlab.http_get(path, **kwargs)
 
 
